



/* enumerations from "mate-app-helper.h" */
    (void) mate_ui_info_type_get_type ();
    (void) mate_ui_info_configurable_types_get_type ();
    (void) mate_ui_pixmap_type_get_type ();

/* enumerations from "mate-client.h" */
    (void) mate_interact_style_get_type ();
    (void) mate_dialog_type_get_type ();
    (void) mate_save_style_get_type ();
    (void) mate_restart_style_get_type ();
    (void) mate_client_state_get_type ();
    (void) mate_client_flags_get_type ();

/* enumerations from "mate-dateedit.h" */
    (void) mate_date_edit_flags_get_type ();

/* enumerations from "mate-druid-page-edge.h" */
    (void) mate_edge_position_get_type ();

/* enumerations from "mate-font-picker.h" */
    (void) mate_font_picker_mode_get_type ();

/* enumerations from "mate-icon-list.h" */
    (void) mate_icon_list_mode_get_type ();

/* enumerations from "mate-icon-lookup.h" */
    (void) mate_icon_lookup_flags_get_type ();
    (void) mate_icon_lookup_result_flags_get_type ();

/* enumerations from "mate-mdi.h" */
    (void) mate_mdi_mode_get_type ();

/* enumerations from "mate-password-dialog.h" */
    (void) mate_password_dialog_remember_get_type ();

/* enumerations from "mate-thumbnail.h" */
    (void) mate_thumbnail_size_get_type ();

/* enumerations from "mate-types.h" */
    (void) mate_preferences_type_get_type ();



